@@ -33,13 +33,18 @@ public:
     static FilterResult* merge(vector<FilterResult*>& list);
     void print();
     // for single end
-    void addAdapterTrimmed(string adapter, bool isR2 = false);
+    void addAdapterTrimmed(string adapter, bool isR2 = false, bool incTrimmedCounter = true);
     // for paired end
     void addAdapterTrimmed(string adapter1, string adapter2);
+    void addPolyXTrimmed(int base, int length);
+    long getTotalPolyXTrimmedReads();
+    long getTotalPolyXTrimmedBases();
     // a part of JSON report
     void reportJson(ofstream& ofs, string padding);
     // a part of JSON report for adapters
     void reportAdapterJson(ofstream& ofs, string padding);
+    // a part of JSON report for polyX trim
+    void reportPolyXTrimJson(ofstream& ofs, string padding);
     // a part of HTML report
     void reportHtml(ofstream& ofs, long totalReads, long totalBases);
     // a part of HTML report for adapters
@@ -54,6 +59,7 @@ public:
     void incCorrectedReads(int count);
     void addMergedPairs(int pairs);
 
+
 public:
     Options* mOptions;
     bool mPaired;
@@ -63,6 +69,8 @@ private:
     long mFilterReadStats[FILTER_RESULT_TYPES];
     long mTrimmedAdapterRead;
     long mTrimmedAdapterBases;
+    long mTrimmedPolyXReads[4] = {0};
+    long mTrimmedPolyXBases[4] = {0};
     map<string, long, classcomp> mAdapter1;
     map<string, long, classcomp> mAdapter2;
     long* mCorrectionMatrix;
