@@ -351,8 +351,11 @@ void HtmlReporter::report(FilterResult* result, Stats* preStats1, Stats* postSta
     ofs << "<div class='section_title' onclick=showOrHide('after_filtering')><a name='summary'>After filtering</a></div>\n";
     ofs << "<div id='after_filtering'>\n";
 
-    if(postStats1) {
-        postStats1 -> reportHtml(ofs, "After filtering", "read1");
+    if(postStats1) {  
+        string name = "read1";
+        if(mOptions->merge.enabled)
+            name = "merged";
+        postStats1 -> reportHtml(ofs, "After filtering", name);
     }
 
     if(postStats2 && !mOptions->merge.enabled) {
@@ -403,7 +406,7 @@ void HtmlReporter::printCSS(ofstream& ofs){
 }
 
 void HtmlReporter::printJS(ofstream& ofs){
-    ofs << "<script src='https://cdn.plot.ly/plotly-latest.min.js'></script>" << endl;
+    ofs << "<script src='http://opengene.org/plotly-1.2.0.min.js'></script>" << endl;
     ofs << "\n<script type=\"text/javascript\">" << endl;
     ofs << "    function showOrHide(divname) {" << endl;
     ofs << "        div = document.getElementById(divname);" << endl;
