@@ -77,6 +77,10 @@ private:
     long* mInsertSizeHist;
     WriterThread* mLeftWriter;
     WriterThread* mRightWriter;
+    WriterThread* mUnpairedLeftWriter;
+    WriterThread* mUnpairedRightWriter;
+    WriterThread* mMergedWriter;
+    WriterThread* mFailedWriter;
     Duplicate* mDuplicate;
 };
 
